@@ -169,6 +169,11 @@ from cyberfusion.ClusterSupport.malwares import (
     MODEL_MALWARES,
     Malware,
 )
+from cyberfusion.ClusterSupport.node_add_ons import (
+    ENDPOINT_NODE_ADD_ONS,
+    MODEL_NODE_ADD_ONS,
+    NodeAddOn,
+)
 from cyberfusion.ClusterSupport.nodes import ENDPOINT_NODES, MODEL_NODES, Node
 from cyberfusion.ClusterSupport.passenger_apps import (
     ENDPOINT_PASSENGER_APPS,
@@ -205,6 +210,10 @@ from cyberfusion.ClusterSupport.service_accounts_to_clusters import (
     ENDPOINT_SERVICE_ACCOUNTS_TO_CLUSTERS,
     ServiceAccountToCluster,
 )
+from cyberfusion.ClusterSupport.service_accounts_to_customers import (
+    ENDPOINT_SERVICE_ACCOUNTS_TO_CUSTOMERS,
+    ServiceAccountToCustomer,
+)
 from cyberfusion.ClusterSupport.ssh_keys import (
     ENDPOINT_SSH_KEYS,
     MODEL_SSH_KEYS,
@@ -288,6 +297,7 @@ class ClusterSupport:
 
     GROUP_NODE_ADMIN = "Admin"
     GROUP_NODE_MEILISEARCH = "Meilisearch"
+    GROUP_NODE_NEW_RELIC = "New Relic"
     GROUP_NODE_COMPOSER = "Composer"
     GROUP_NODE_KERNELCARE = "KernelCare"
     GROUP_NODE_WP_CLI = "WP-CLI"
@@ -380,6 +390,13 @@ class ClusterSupport:
         """Get object(s) from API."""
         return self._get_objects(Node, ENDPOINT_NODES, MODEL_NODES)
 
+    @cached_property
+    def node_add_ons(self) -> List[Node]:
+        """Get object(s) from API."""
+        return self._get_objects(
+            NodeAddOn, ENDPOINT_NODE_ADD_ONS, MODEL_NODE_ADD_ONS
+        )
+
     def _get_current_node(self) -> Optional[Node]:
         """Get Node object for node we're running on."""
         try:
@@ -783,6 +800,14 @@ class ClusterSupport:
             ENDPOINT_SERVICE_ACCOUNTS_TO_CLUSTERS,
         )
 
+    @cached_property
+    def service_accounts_to_customers(self) -> List[ServiceAccountToCustomer]:
+        """Get object(s) from API."""
+        return self._get_objects(
+            ServiceAccountToCustomer,
+            ENDPOINT_SERVICE_ACCOUNTS_TO_CUSTOMERS,
+        )
+
     def task_collection_results(
         self,
         task_collection_uuid: str,
@@ -1281,6 +1306,10 @@ class ClusterSupport:
         """Get object from loaded objects."""
         return self._filter_objects(self.haproxy_listens, **kwargs)
 
+    def get_node_add_ons(self, **kwargs: Any) -> List[NodeAddOn]:
+        """Get object from loaded objects."""
+        return self._filter_objects(self.node_add_ons, **kwargs)
+
     def get_haproxy_listens_to_nodes(
         self, **kwargs: Any
     ) -> List[HAProxyListenToNode]:
@@ -1351,6 +1380,14 @@ class ClusterSupport:
             self.service_accounts_to_clusters, **kwargs
         )
 
+    def get_service_accounts_to_customers(
+        self, **kwargs: Any
+    ) -> List[ServiceAccountToCustomer]:
+        """Get object from loaded objects."""
+        return self._filter_objects(
+            self.service_accounts_to_customers, **kwargs
+        )
+
     def get_table(
         self,
         *,
@@ -1376,7 +1413,7 @@ class ClusterSupport:
         )
 
         for header in headers:
-            table.add_column(header)
+            table.add_column(header, overflow="fold")
 
         for obj in objs:
             fields = []
@@ -1461,8 +1498,8 @@ class ClusterSupport:
             items.sort(key=lambda item: item[0])
 
         table = Table()
-        table.add_column(left_column_name)
-        table.add_column(right_column_name)
+        table.add_column(left_column_name, overflow="fold")
+        table.add_column(right_column_name, overflow="fold")
 
         for row in items:
             table.add_row(f"[{row[2]}]{row[0]}", f"[{row[2]}]{row[1]}")
