@@ -13,6 +13,8 @@ class ObjectModelName(str, Enum):
     FPM_POOL: str = "FPMPool"
     VIRTUAL_HOST: str = "VirtualHost"
     PASSENGER_APP: str = "PassengerApp"
+    SERVICE_ACCOUNT_TO_CLUSTER: str = "ServiceAccountToCluster"
+    SERVICE_ACCOUNT_TO_CUSTOMER: str = "ServiceAccountToCustomer"
     DATABASE: str = "Database"
     CERTIFICATE_MANAGER: str = "CertificateManager"
     BASIC_AUTHENTICATION_REALM: str = "BasicAuthenticationRealm"
@@ -25,6 +27,7 @@ class ObjectModelName(str, Enum):
     MAIL_ALIASES: str = "MailAlias"
     MAIL_DOMAIN: str = "MailDomain"
     NODE: str = "Node"
+    NODE_ADD_ON: str = "NodeAddOn"
     REDIS_INSTANCE: str = "RedisInstance"
     DOMAIN_ROUTER: str = "DomainRouter"
     MAIL_HOSTNAME: str = "MailHostname"
