@@ -25,6 +25,6 @@ class ServiceAccountServerFactory(BaseBackendFactory):
         "cyberfusion.ClusterSupport.tests_factories.service_accounts.ServiceAccountFactory",
     )
     netbox_resource_type = factory.fuzzy.FuzzyChoice(NetBoxResourceType)
-    netbox_resource_id = 1
-    netbox_parent_interface_id = 1
+    netbox_resource_id = factory.Faker("random_int")
+    netbox_parent_interface_id = factory.Faker("random_int")
     service_account_id = factory.SelfAttribute("service_account.id")
