@@ -19,4 +19,12 @@ class ServiceAccountFactory(BaseBackendFactory):
         model = ServiceAccount
 
     name = factory.Faker("domain_name")
-    group = factory.fuzzy.FuzzyChoice(ServiceAccountGroup)
+    group = ServiceAccountGroup.MAIL_PROXY
+    default_ipv6_ip_address = None
+    default_ipv4_ip_address = None
+    default_ipv6_netbox_id = None
+    default_ipv4_netbox_id = None
+    netbox_additional_prefix_ipv4_id = None
+    netbox_fhrp_group_ipv6_id = None
+    netbox_fhrp_group_ipv4_id = None
+    netbox_additional_prefix_ipv6_id = None
